@@ -19,7 +19,7 @@ package Astro::ADS::Query;
 #    Alasdair Allan (aa@astro.ex.ac.uk)
 
 #  Revision:
-#     $Id: Query.pm,v 1.21 2002/09/23 21:07:49 aa Exp $
+#     $Id: Query.pm,v 1.16 2001/11/10 17:35:52 aa Exp $
 
 #  Copyright:
 #     Copyright (C) 2001 University of Exeter. All Rights Reserved.
@@ -37,11 +37,7 @@ Astro::ADS::Query - Object definining an prospective ADS query.
   $query = new Astro::ADS::Query( Authors     => \@authors,
                                   AuthorLogic => $aut_logic,
                                   Objects     => \@objects,
-                                  ObjectLogic => $obj_logic, 
-                                  Bibcode     => $bibcode,
-                                  Proxy       => $proxy,
-                                  Timeout     => $timeout,
-                                  URL         => $url );
+                                  ObjectLogic => $obj_logic  );
 
   my $results = $query->querydb();
 
@@ -64,16 +60,15 @@ use vars qw/ $VERSION /;
 use LWP::UserAgent;
 use Astro::ADS::Result;
 use Astro::ADS::Result::Paper;
-use Net::Domain qw(hostname hostdomain);
 use Carp;
 
-'$Revision: 1.21 $ ' =~ /.*:\s(.*)\s\$/ && ($VERSION = $1);
+'$Revision: 1.16 $ ' =~ /.*:\s(.*)\s\$/ && ($VERSION = $1);
 
 # C O N S T R U C T O R ----------------------------------------------------
 
 =head1 REVISION
 
-$Id: Query.pm,v 1.21 2002/09/23 21:07:49 aa Exp $
+$Id: Query.pm,v 1.16 2001/11/10 17:35:52 aa Exp $
 
 =head1 METHODS
 
@@ -88,11 +83,7 @@ Create a new instance from a hash of options
   $query = new Astro::ADS::Query( Authors     => \@authors,
                                   AuthorLogic => $aut_logic,
                                   Objects     => \@objects,
-                                  ObjectLogic => $obj_logic, 
-                                  Bibcode     => $bibcode,
-                                  Proxy       => $proxy,
-                                  Timeout     => $timeout,
-                                  URL         => $url );
+                                  ObjectLogic => $obj_logic );
 
 returns a reference to an ADS query object.
 
@@ -105,7 +96,6 @@ sub new {
   # bless the query hash into the class
   my $block = bless { OPTIONS   => {},
                       URL       => undef,
-                      QUERY     => undef,
                       FOLLOWUP  => undef,
                       USERAGENT => undef,
                       BUFFER    => undef }, $class;
@@ -230,49 +220,6 @@ sub timeout {
 
 }
 
-=item B<url>
-
-Return (or set) the current base URL for the ADS query.
-
-   $url = $query->url();
-   $query->url( "adsabs.harvard.edu" );
-
-if not defined the default URL is cdsads.u-strasbg.fr
-
-=cut
-
-sub url {
-  my $self = shift;
-
-  # SETTING URL
-  if (@_) { 
-
-    # set the url option 
-    my $base_url = shift; 
-    $self->{URL} = $base_url;
-    if( defined $base_url ) {
-       $self->{QUERY} = "http://$base_url/cgi-bin/nph-abs_connect?";
-       $self->{FOLLOWUP} = "http://$base_url/cgi-bin/nph-ref_query?";
-    }
-  }
-
-  # RETURNING URL
-  return $self->{URL};
-}
-
-=item B<agent>
-
-Returns the user agent tag sent by the module to the ADS server.
-
-   $agent_tag = $query->agent();
-
-=cut
-
-sub agent {
-  my $self = shift;
-  return $self->{USERAGENT}->agent();
-}
-
 # O T H E R   M E T H O D S ------------------------------------------------
 
 =item B<Authors>
@@ -452,140 +399,6 @@ sub bibcode {
   return ${$self->{OPTIONS}}{"bibcode"};
 }
 
-
-=item B<startmonth>
-
-Return (or set) the current starting month of the ADS query.
-
-   $start_month = $query->startmonth();
-   $query->startmonth( "01" );
-
-=cut
-
-sub startmonth {
-  my $self = shift;
-
-  # SETTING STARTING MONTH
-  if (@_) { 
-
-    # set the starting month option  
-    ${$self->{OPTIONS}}{"start_mon"} = shift;
-  }
-
-  # RETURNING STARTING MONTH
-  return ${$self->{OPTIONS}}{"start_mon"};
-
-}
-
-=item B<endmonth>
-
-Return (or set) the current end month of the ADS query.
-
-   $end_month = $query->endmonth();
-   $query->endmonth( "12" );
-
-=cut
-
-sub endmonth {
-  my $self = shift;
-
-  # SETTING END MONTH
-  if (@_) { 
-
-    # set the end month option  
-    ${$self->{OPTIONS}}{"end_mon"} = shift;
-  }
-
-  # RETURNING END MONTH
-  return ${$self->{OPTIONS}}{"end_mon"};
-
-}
-
-=item B<startyear>
-
-Return (or set) the current starting year of the ADS query.
-
-   $start_year = $query->startyear();
-   $query->start_year( "2001" );
-
-=cut
-
-sub startyear {
-  my $self = shift;
-
-  # SETTING START YEAR
-  if (@_) { 
-
-    # set the starting year option  
-    ${$self->{OPTIONS}}{"start_year"} = shift;
-  }
-
-  # RETURNING START YEAR
-  return ${$self->{OPTIONS}}{"start_year"};
-
-}
-
-=item B<endyear>
-
-Return (or set) the current end year of the ADS query.
-
-   $end_year = $query->endyear();
-   $query->end_year( "2002" );
-
-=cut
-
-sub endyear {
-  my $self = shift;
-
-  # SETTING END YEAR
-  if (@_) { 
-
-    # set the end year option  
-    ${$self->{OPTIONS}}{"end_year"} = shift;
-  }
-
-  # RETURNING END YEAR
-  return ${$self->{OPTIONS}}{"end_year"};
-
-}
-
-=item B<journal>
-
-Return (or set) whether refereed, non-refereed (OTHER) or all bibilographic sources (ALL) are returned.
-
-   $query->journal( "REFEREED" );
-   $query->journal( "OTHER" );
-   $query->journal( "ALL" );
-   
-   $journals = $query->journal();
-
-the default is ALL bibilographic sources
-
-=cut
-
-sub journal {
-  my $self = shift;
-
-  # SETTING END YEAR
-  if (@_) { 
-
-    my $source = shift;
-    
-    if ( $source eq "REFEREED" ) {
-       ${$self->{OPTIONS}}{"jou_pick"} = "NO";
-    } elsif ( $source eq "OTHER" ) {
-       ${$self->{OPTIONS}}{"jou_pick"} = "EXCL";
-    } else {
-       ${$self->{OPTIONS}}{"jou_pick"} = "ALL";
-    }  
-
-  }
-
-  # RETURNING END YEAR
-  return ${$self->{OPTIONS}}{"jou_pick"};
-
-}
-
 # C O N F I G U R E -------------------------------------------------------
 
 =back
@@ -602,6 +415,18 @@ Configures the object, takes an options hash as an argument
 
 Does nothing if the array is not supplied.
 
+=over 4
+
+=item B<Authors>
+
+A list of authors for the query. By default author logic is set to OR rather
+than the potentially more useful AND.
+
+=item B<AuthorLogic>
+
+By default the author logic, i.e. how the author names are combined during
+the search, is set to OR. Other options include; AND, combine with AND; SIMPLE, use simple logic (use +,-); BOOL, full boolean logic and FULLMATCH, do an AND query and calculate the score according to how many words in the author field match in the paper.
+
 =cut
 
 sub configure {
@@ -610,20 +435,12 @@ sub configure {
   # CONFIGURE DEFAULTS
   # ------------------
 
-  # define the default base URL
-  $self->{URL} = "cdsads.u-strasbg.fr";
-  
-  # define the query URLs
-  my $default_url = $self->{URL};
-  $self->{QUERY} = "http://$default_url/cgi-bin/nph-abs_connect?";
-  $self->{FOLLOWUP} = "http://$default_url/cgi-bin/nph-ref_query?";
+  # define the default base URLs
+  $self->{URL} = "http://cdsads.u-strasbg.fr/cgi-bin/nph-abs_connect?";
+  $self->{FOLLOWUP} = "http://cdsads.u-strasbg.fr/cgi-bin/nph-ref_query?";
 
-   
   # Setup the LWP::UserAgent
-  my $HOST = hostname();
-  my $DOMAIN = hostdomain();
   $self->{USERAGENT} = new LWP::UserAgent( timeout => 30 ); 
-  $self->{USERAGENT}->agent("Astro::ADS/$VERSION ($HOST.$DOMAIN)");
 
   # Grab Proxy details from local environment
   $self->{USERAGENT}->env_proxy();
@@ -673,9 +490,7 @@ sub configure {
   ${$self->{OPTIONS}}{"bibcode"}          = "";
 
   # Set the data_type option to PORTABLE so our regular expressions work!
-  # Set the return format to LONG so we get full abstracts!
   ${$self->{OPTIONS}}{"data_type"}        = "PORTABLE";
-  ${$self->{OPTIONS}}{"return_fmt"}       = "LONG";
 
   # CONFIGURE FROM ARGUEMENTS
   # -------------------------
@@ -687,9 +502,7 @@ sub configure {
   my %args = @_;
 
   # Loop over the allowed keys and modify the default query options
-  for my $key (qw / Authors AuthorLogic Objects ObjectLogic Bibcode 
-                    StartMonth EndMonth StartYear EndYear Journal
-                    Proxy Timeout URL/ ) {
+  for my $key (qw / Authors AuthorLogic Objects ObjectLogic Bibcode / ) {
       my $method = lc($key);
       $self->$method( $args{$key} ) if exists $args{$key};
   }
@@ -725,7 +538,7 @@ sub _make_query {
    $self->{BUFFER} = "";
 
    # grab the base URL
-   my $URL = $self->{QUERY};
+   my $URL = $self->{URL};
    my $options = "";
 
    # loop round all the options keys and build the query
@@ -735,7 +548,7 @@ sub _make_query {
 
    # build final query URL
    $URL = $URL . $options;
-   
+
    # build request
    my $request = new HTTP::Request('GET', $URL);
 
@@ -743,43 +556,12 @@ sub _make_query {
    my $reply = $ua->request($request);
 
    if ( ${$reply}{"_rc"} eq 200 ) {
-   
       # stuff the page contents into the buffer
       $self->{BUFFER} = ${$reply}{"_content"};
-      
-   } elsif ( ${$reply}{"_rc"} eq 500 ) {
-   
-      # we may have a network unreachable, or we may have a no reference
-      # selected error returned by ADS (go figure)
-
-      $self->{BUFFER} = ${$reply}{"_content"};
-      my @buffer = split( /\n/,$self->{BUFFER});
-      chomp @buffer;
-            
-      # assume we have an error unless we can prove otherwise
-      my $error_flag = 1;
-      
-      foreach my $line ( 0 ... $#buffer ) {
-          if( $buffer[$line] =~ "No reference selected" ) {
-       
-             # increment the counter and drop out of the loop
-             $line = $#buffer;
-             $error_flag = 0;
-          }      
-      }
-      
-      # we definately have an error
-      if( $error_flag ) { 
-         $self->{BUFFER} = undef;
-         croak("Error ${$reply}{_rc}: Failed to establish network connection");
-      }
-      
    } else {
       $self->{BUFFER} = undef;
       croak("Error ${$reply}{_rc}: Failed to establish network connection");
    }
-   
-   
 }
 
 =item B<_make_followup>
@@ -810,10 +592,10 @@ sub _make_followup {
    # which database?
    my $db_key = ${$self->{OPTIONS}}{"db_key"};
    my $data_type = ${$self->{OPTIONS}}{"data_type"};
-   my $fmt = ${$self->{OPTIONS}}{"return_fmt"};
 
    # build the final query URL
-   $URL = $URL . "bibcode=$bibcode&refs=$refs&db_key=$db_key&data_type=$data_type&return_fmt=$fmt"; 
+   $URL = $URL .
+          "bibcode=$bibcode&refs=$refs&db_key=$db_key&data_type=$data_type"; 
 
    # build request
    my $request = new HTTP::Request('GET', $URL);
@@ -826,7 +608,7 @@ sub _make_followup {
       $self->{BUFFER} = ${$reply}{"_content"};
    } else {
       $self->{BUFFER} = undef;
-      croak("Error ${$reply}{_rc}: Failed to establish network connection" . $self->{BUFFER} ."\n");
+      croak("Error ${$reply}{_rc}: Failed to establish network connection");
    }
 }
 
@@ -875,16 +657,8 @@ sub _parse_query {
 
         # increment the counter and drop out of the loop
         $line = $#buffer;
-        
      }
-     
-     # NO ABSTRACT (HTML version)
-     if( $buffer[$line] =~ "No reference selected" ) {
-       
-       # increment the counter and drop out of the loop
-        $line = $#buffer;
-     }
-     
+
      # NEW PAPER
      if( substr( $buffer[$line], 0, 2 ) eq "%R" ) {
 
@@ -893,7 +667,6 @@ sub _parse_query {
 
         # grab the bibcode
         my $bibcode = substr( $buffer[$counter], 2 );
-        $bibcode =~ s/\s+//g;
 
         # New Astro::ADS::Result::Paper object
         $paper = new Astro::ADS::Result::Paper( Bibcode => $bibcode );
